@@ -3,7 +3,7 @@ context("Testing dual-host with continuous structure")
 test_that("Both hosts move", {
   library(raster)
 
-  #Generating a raster the for movement
+  #Generating a raster for the movement
   set.seed(860)
 
   test.raster <- raster(nrows=100, ncols=100, xmn=-50, xmx=50, ymn=-50,ymx=50)
@@ -90,6 +90,9 @@ test_that("Both hosts move", {
                           diff.pTrans.B=FALSE,
                           prefix.host.B="V")
 
+  ## Output
+  expect_output(print(test.nosoiA), "a dual host with a continuous structure")
+
   full.results.nosoi <- rbindlist(list(test.nosoiA$host.info.A$table.hosts,test.nosoiA$host.info.B$table.hosts))
   full.results.nosoi.state <- rbindlist(list(test.nosoiA$host.info.A$table.state,test.nosoiA$host.info.B$table.state))
 
@@ -121,16 +124,20 @@ test_that("Both hosts move", {
   dynNew <- getDynamic(test.nosoiA)
   expect_equal(dynOld, dynNew)
 
-  r_0_old <- getR0Old(test.nosoiA)
   r_0 <- getR0(test.nosoiA)
-  expect_equal(r_0_old$R0.mean, r_0$R0.mean)
+  expect_equal(r_0$N.inactive.A,
+               ifelse(length(r_0$R0.hostA.dist) == 1 && is.na(r_0$R0.hostA.dist),
+                      0, length(r_0$R0.hostA.dist)))
+  expect_equal(r_0$N.inactive.B,
+               ifelse(length(r_0$R0.hostB.dist) == 1 && is.na(r_0$R0.hostB.dist),
+                      0, length(r_0$R0.hostB.dist)))
 })
 
 
 test_that("One host (A) moves", {
   library(raster)
 
-  #Generating a raster the for movement
+  #Generating a raster for the movement
   set.seed(860)
 
   test.raster <- raster(nrows=100, ncols=100, xmn=-50, xmx=50, ymn=-50,ymx=50)
@@ -255,15 +262,19 @@ test_that("One host (A) moves", {
   dynNew <- getDynamic(test.nosoiA)
   expect_equal(dynOld, dynNew)
 
-  r_0_old <- getR0Old(test.nosoiA)
   r_0 <- getR0(test.nosoiA)
-  expect_equal(r_0_old$R0.mean, r_0$R0.mean)
+  expect_equal(r_0$N.inactive.A,
+               ifelse(length(r_0$R0.hostA.dist) == 1 && is.na(r_0$R0.hostA.dist),
+                      0, length(r_0$R0.hostA.dist)))
+  expect_equal(r_0$N.inactive.B,
+               ifelse(length(r_0$R0.hostB.dist) == 1 && is.na(r_0$R0.hostB.dist),
+                      0, length(r_0$R0.hostB.dist)))
 })
 
 test_that("One host (B) moves", {
   library(raster)
 
-  #Generating a raster the for movement
+  #Generating a raster for the movement
   set.seed(860)
 
   test.raster <- raster(nrows=100, ncols=100, xmn=-50, xmx=50, ymn=-50,ymx=50)
@@ -387,15 +398,19 @@ test_that("One host (B) moves", {
   dynNew <- getDynamic(test.nosoiA)
   expect_equal(dynOld, dynNew)
 
-  r_0_old <- getR0Old(test.nosoiA)
   r_0 <- getR0(test.nosoiA)
-  expect_equal(r_0_old$R0.mean, r_0$R0.mean)
+  expect_equal(r_0$N.inactive.A,
+               ifelse(length(r_0$R0.hostA.dist) == 1 && is.na(r_0$R0.hostA.dist),
+                      0, length(r_0$R0.hostA.dist)))
+  expect_equal(r_0$N.inactive.B,
+               ifelse(length(r_0$R0.hostB.dist) == 1 && is.na(r_0$R0.hostB.dist),
+                      0, length(r_0$R0.hostB.dist)))
 })
 
 test_that("Epidemic dies out", {
   library(raster)
 
-  #Generating a raster the for movement
+  #Generating a raster for the movement
   set.seed(860)
 
   test.raster <- raster(nrows=100, ncols=100, xmn=-50, xmx=50, ymn=-50,ymx=50)
@@ -506,15 +521,19 @@ test_that("Epidemic dies out", {
   dynNew <- getDynamic(test.nosoiA)
   expect_equal(dynOld, dynNew)
 
-  r_0_old <- getR0Old(test.nosoiA)
   r_0 <- getR0(test.nosoiA)
-  expect_equal(r_0_old$R0.mean, r_0$R0.mean)
+  expect_equal(r_0$N.inactive.A,
+               ifelse(length(r_0$R0.hostA.dist) == 1 && is.na(r_0$R0.hostA.dist),
+                      0, length(r_0$R0.hostA.dist)))
+  expect_equal(r_0$N.inactive.B,
+               ifelse(length(r_0$R0.hostB.dist) == 1 && is.na(r_0$R0.hostB.dist),
+                      0, length(r_0$R0.hostB.dist)))
 })
 
 test_that("Error if no host move", {
   library(raster)
 
-  #Generating a raster the for movement
+  #Generating a raster for the movement
   set.seed(860)
 
   test.raster <- raster(nrows=100, ncols=100, xmn=-50, xmx=50, ymn=-50,ymx=50)
@@ -607,7 +626,7 @@ test_that("Error if no host move", {
 test_that("One host (B) moves, host count", {
   library(raster)
 
-  #Generating a raster the for movement
+  #Generating a raster for the movement
   set.seed(860)
 
   test.raster <- raster(nrows=100, ncols=100, xmn=-50, xmx=50, ymn=-50,ymx=50)
@@ -744,7 +763,11 @@ test_that("One host (B) moves, host count", {
   dynNew <- getDynamic(test.nosoiA)
   expect_equal(dynOld, dynNew)
 
-  r_0_old <- getR0Old(test.nosoiA)
   r_0 <- getR0(test.nosoiA)
-  expect_equal(r_0_old$R0.mean, r_0$R0.mean)
+  expect_equal(r_0$N.inactive.A,
+               ifelse(length(r_0$R0.hostA.dist) == 1 && is.na(r_0$R0.hostA.dist),
+                      0, length(r_0$R0.hostA.dist)))
+  expect_equal(r_0$N.inactive.B,
+               ifelse(length(r_0$R0.hostB.dist) == 1 && is.na(r_0$R0.hostB.dist),
+                      0, length(r_0$R0.hostB.dist)))
 })
